summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteaccountmanager.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kopete/libkopete/kopeteaccountmanager.h
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kopete/libkopete/kopeteaccountmanager.h')
-rw-r--r--kopete/libkopete/kopeteaccountmanager.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/libkopete/kopeteaccountmanager.h b/kopete/libkopete/kopeteaccountmanager.h
index f1ba6443..a8163245 100644
--- a/kopete/libkopete/kopeteaccountmanager.h
+++ b/kopete/libkopete/kopeteaccountmanager.h
@@ -196,11 +196,11 @@ signals:
* \brief An account has changed its onlinestatus
* Technically this monitors Account::myself() onlinestatus changes
* \param account Account which changed its onlinestatus
* \param oldStatus The online status before the change
* \param newStatus The new online status
*/
void accountOnlineStatusChanged(Kopete::Account *account,
- const Kopete::OnlineStatus &oldStatus, const Kopete::OnlineStatus &newStatus);
+ const Kopete::OnlineStatus &oldtqStatus, const Kopete::OnlineStatus &newtqStatus);
private:
/**
@@ -211,7 +211,7 @@ private:
private slots:
void slotPluginLoaded( Kopete::Plugin *plugin );
void slotAccountOnlineStatusChanged(Kopete::Contact *c,
- const Kopete::OnlineStatus &oldStatus, const Kopete::OnlineStatus &newStatus);
+ const Kopete::OnlineStatus &oldtqStatus, const Kopete::OnlineStatus &newtqStatus);
/**
* \internal
@@ -196,11 +196,11 @@ signals:
* Technically this monitors Account::myself() onlinestatus changes
* \param account Account which changed its onlinestatus
- * \param oldStatus The online status before the change
- * \param newStatus The new online status
+ * \param oldtqStatus The online status before the change
+ * \param newtqStatus The new online status
*/
void accountOnlineStatusChanged(Kopete::Account *account,